.. foremast documentation master file, created by
   sphinx-quickstart on Mon Jul 11 14:16:24 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _home:

Welcome to foremast's documentation!
====================================

Contents
--------

.. toctree::
   :maxdepth: 2
   :titlesonly:

   getting_started
   pipeline_examples
   configuration_files/index
   advance_usages
   infra_assumptions
   lambda/index
   s3/index
   halyard/index
   CONTRIBUTING
   RELEASING
   foremast/modules
   CHANGELOG

.. include:: ../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
